# Common

As it sounds, it gathers commonly used code around the system

`messaging` and `queue` holds the part of the websocket and queing functionality that is share between the client and the server 
`security` handles general authentication functionality, groups and permissioning
`aspect_utilities` is for supporting the wide use of AOP in the system
